@@ -43,7 +43,7 @@ ImportDialog::ImportDialog(CoreInterface *core, QWidget *parent)
     setupUi(this);
     KUrlRequester *r = m_torrent_url;
     r->setMode(KFile::File | KFile::LocalOnly);
-    r->setFilter(kt::TorrentFileFilter(true, FilterKUrlRequester));
+    r->setNameFilters(QStringList(kt::TorrentFileFilter(true, FilterKUrlRequester)));
 
     r = m_data_url;
     r->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);
@@ -69,7 +69,7 @@ void ImportDialog::progress(quint32 num, quint32 total)
 void ImportDialog::finished()
 {
     QString data_dir = m_data_url->url().toLocalFile();
-    QUrl tor_url = m_torrent_url->url();
+    QString torrent_path = m_torrent_url->url().toLocalFile();
     if (canceled || !dc_thread->getError().isEmpty()) {
         if (!canceled)
             KMessageBox::error(this, dc_thread->getError());
@@ -92,7 +92,7 @@ void ImportDialog::finished()
         writeIndex(tor_dir + QStringLiteral("index"), dc->getResult());
 
         // copy the torrent file
-        bt::CopyFile(tor_url.url(), tor_dir + QStringLiteral("torrent"));
+        bt::CopyFile(torrent_path, tor_dir + QStringLiteral("torrent"));
 
         Uint64 imported = calcImportedBytes(dc->getResult(), tor);
 
@@ -120,7 +120,7 @@ void ImportDialog::finished()
             // if (durl.endsWith(bt::DirSeparator()))
             durl.chop(1);
             int ds = durl.lastIndexOf(bt::DirSeparator());
-            if (durl.midRef(ds + 1) == tor.getNameSuggestion()) {
+            if (QStringView{durl}.sliced(ds + 1) == tor.getNameSuggestion()) {
                 durl.truncate(ds);
                 saveStats(tor_dir + QStringLiteral("stats"), durl, imported, false);
             } else {
