@@ -17,6 +17,7 @@
 #include <KConfig>
 #include <KEditToolBar>
 #include <KFileWidget>
+#include <KGlobalAccel>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KMessageBox>
@@ -203,9 +204,11 @@ void GUI::mergePluginGui(Plugin *p)
 
 void GUI::removePluginGui(Plugin *p)
 {
-    if (p->parentPart() == QStringLiteral("ktorrent")) {
-        guiFactory()->removeClient(p);
-    } else {
+    if (p->factory()) {
+        p->factory()->removeClient(p);
+    }
+
+    if (p->parentPart() != QStringLiteral("ktorrent")) {
         const QList<KParts::Part *> parts = part_manager->parts();
         for (KParts::Part *part : parts) {
             if (part->domDocument().documentElement().attribute(QStringLiteral("name")) == p->parentPart()) {
@@ -326,7 +329,8 @@ void GUI::configureKeys()
 
 void GUI::configureToolbars()
 {
-    // KF5 saveMainWindowSettings(KSharedConfig::openConfig()->group("MainWindow"));
+    auto main_window_group = KSharedConfig::openConfig()->group(QStringLiteral("MainWindow"));
+    saveMainWindowSettings(main_window_group);
     KEditToolBar dlg(factory());
     connect(&dlg, &KEditToolBar::newToolBarConfig, this, &GUI::newToolBarConfig);
     dlg.exec();
@@ -338,7 +342,7 @@ void GUI::configureToolbars()
 
 void GUI::newToolBarConfig() // This is called when OK, Apply or Defaults is clicked
 {
-    applyMainWindowSettings(KSharedConfig::openConfig()->group("MainWindow"));
+    applyMainWindowSettings(KSharedConfig::openConfig()->group(QStringLiteral("MainWindow")));
 }
 
 void GUI::import()
@@ -376,24 +380,24 @@ void GUI::setupActions()
     paste_url_action->setToolTip(i18n("Open a URL which points to a torrent, magnet links are supported"));
     connect(paste_url_action, &QAction::triggered, this, &GUI::pasteURL);
     ac->addAction(QStringLiteral("paste_url"), paste_url_action);
-    ac->setDefaultShortcut(paste_url_action, QKeySequence(Qt::CTRL + Qt::Key_P));
+    ac->setDefaultShortcut(paste_url_action, QKeySequence(Qt::CTRL | Qt::Key_P));
 
     ipfilter_action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), i18n("IP Filter"), this);
     ipfilter_action->setToolTip(i18n("Show the list of blocked IP addresses"));
     connect(ipfilter_action, &QAction::triggered, this, &GUI::showIPFilter);
     ac->addAction(QStringLiteral("ipfilter_action"), ipfilter_action);
-    ac->setDefaultShortcut(ipfilter_action, QKeySequence(Qt::CTRL + Qt::Key_I));
+    ac->setDefaultShortcut(ipfilter_action, QKeySequence(Qt::CTRL | Qt::Key_I));
 
     import_action = new QAction(QIcon::fromTheme(QStringLiteral("document-import")), i18n("Import Torrent"), this);
     import_action->setToolTip(i18n("Import a torrent"));
     connect(import_action, &QAction::triggered, this, &GUI::import);
     ac->addAction(QStringLiteral("import"), import_action);
-    ac->setDefaultShortcut(import_action, QKeySequence(Qt::SHIFT + Qt::Key_I));
+    ac->setDefaultShortcut(import_action, QKeySequence(Qt::SHIFT | Qt::Key_I));
 
     show_kt_action = new QAction(QIcon::fromTheme(QStringLiteral("kt-show-hide")), i18n("Show/Hide KTorrent"), this);
     connect(show_kt_action, &QAction::triggered, this, &GUI::showOrHide);
     ac->addAction(QStringLiteral("show_kt"), show_kt_action);
-    // KF5 show_kt_action->setGlobalShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_T));
+    KGlobalAccel::setGlobalShortcut(show_kt_action, QKeySequence(Qt::ALT | Qt::SHIFT | Qt::Key_T));
 
     setStandardToolBarMenuEnabled(true);
 }
@@ -438,7 +442,7 @@ void GUI::loadState(KSharedConfigPtr cfg)
     central->loadState(cfg);
     torrent_activity->loadState(cfg);
 
-    KConfigGroup g = cfg->group("MainWindow");
+    KConfigGroup g = cfg->group(QStringLiteral("MainWindow"));
     bool statusbar_hidden = g.readEntry("statusbar_hidden", false);
     status_bar->setHidden(statusbar_hidden);
     show_status_bar_action->setChecked(!statusbar_hidden);
@@ -460,7 +464,7 @@ void GUI::loadState(KSharedConfigPtr cfg)
 
 void GUI::saveState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("MainWindow");
+    KConfigGroup g = cfg->group(QStringLiteral("MainWindow"));
     saveMainWindowSettings(g);
     g.writeEntry("statusbar_hidden", status_bar->isHidden());
     g.writeEntry("menubar_hidden", menuBar()->isHidden());
