@@ -17,11 +17,10 @@
 
 #include <KActionCollection>
 #include <KFileWidget>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KMessageBox_KTCompat>
 #include <KRecentDirs>
 #include <KSharedConfig>
 #include <KStandardAction>
@@ -53,7 +52,7 @@ namespace kt
 void openUrl(const QUrl &url)
 {
     auto job = new KIO::OpenUrlJob(url);
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
     job->start();
 }
 
@@ -81,6 +80,7 @@ View::View(Core *core, GUI *gui, QWidget *parent)
     setAcceptDrops(true);
     setDragDropMode(DragDrop);
     setUniformRowHeights(true);
+    setProperty("_breeze_force_frame", false);
 
     connect(this, &View::customContextMenuRequested, this, &View::showMenu);
 
@@ -133,7 +133,7 @@ void View::setupActions(KActionCollection *ac)
     start_torrent->setToolTip(i18n("Start all selected torrents in the current tab"));
     connect(start_torrent, &QAction::triggered, this, &View::startTorrents);
     ac->addAction(QStringLiteral("start"), start_torrent);
-    ac->setDefaultShortcut(start_torrent, QKeySequence(Qt::CTRL + Qt::Key_S));
+    ac->setDefaultShortcut(start_torrent, QKeySequence(Qt::CTRL | Qt::Key_S));
 
     force_start_torrent =
         new QAction(QIcon::fromTheme(QStringLiteral("kt-start")), i18nc("@action Force start all selected torrents in the current tab", "Force Start"), this);
@@ -145,7 +145,7 @@ void View::setupActions(KActionCollection *ac)
     stop_torrent->setToolTip(i18n("Stop all selected torrents in the current tab"));
     connect(stop_torrent, &QAction::triggered, this, &View::stopTorrents);
     ac->addAction(QStringLiteral("stop"), stop_torrent);
-    ac->setDefaultShortcut(stop_torrent, QKeySequence(Qt::CTRL + Qt::Key_H));
+    ac->setDefaultShortcut(stop_torrent, QKeySequence(Qt::CTRL | Qt::Key_H));
 
     pause_torrent = new QAction(QIcon::fromTheme(QStringLiteral("media-playback-pause")), //
                                 i18nc("@action Pause all selected torrents in the current tab", "Pause"),
@@ -160,24 +160,24 @@ void View::setupActions(KActionCollection *ac)
     remove_torrent->setToolTip(i18n("Remove all selected torrents in the current tab"));
     connect(remove_torrent, &QAction::triggered, this, &View::removeTorrents);
     ac->addAction(QStringLiteral("remove"), remove_torrent);
-    ac->setDefaultShortcut(remove_torrent, QKeySequence(Qt::SHIFT + Qt::Key_Delete));
+    ac->setDefaultShortcut(remove_torrent, QKeySequence(Qt::SHIFT | Qt::Key_Delete));
 
     start_all = new QAction(QIcon::fromTheme(QStringLiteral("kt-start-all")), i18nc("@action Start all torrents in the current tab", "Start All"), this);
     start_all->setToolTip(i18n("Start all torrents in the current tab"));
     connect(start_all, &QAction::triggered, this, &View::startAllTorrents);
     ac->addAction(QStringLiteral("start_all"), start_all);
-    ac->setDefaultShortcut(start_all, QKeySequence(Qt::SHIFT + Qt::Key_S));
+    ac->setDefaultShortcut(start_all, QKeySequence(Qt::SHIFT | Qt::Key_S));
 
     stop_all = new QAction(QIcon::fromTheme(QStringLiteral("kt-stop-all")), i18nc("@action Stop all torrents in the current tab", "Stop All"), this);
     stop_all->setToolTip(i18n("Stop all torrents in the current tab"));
     connect(stop_all, &QAction::triggered, this, &View::stopAllTorrents);
     ac->addAction(QStringLiteral("stop_all"), stop_all);
-    ac->setDefaultShortcut(stop_all, QKeySequence(Qt::SHIFT + Qt::Key_H));
+    ac->setDefaultShortcut(stop_all, QKeySequence(Qt::SHIFT | Qt::Key_H));
 
     remove_torrent_and_data = new QAction(QIcon::fromTheme(QStringLiteral("kt-remove")), i18n("Remove Torrent and Data"), this);
     connect(remove_torrent_and_data, &QAction::triggered, this, &View::removeTorrentsAndData);
     ac->addAction(QStringLiteral("view_remove_torrent_and_data"), remove_torrent_and_data);
-    ac->setDefaultShortcut(remove_torrent_and_data, QKeySequence(Qt::CTRL + Qt::Key_Delete));
+    ac->setDefaultShortcut(remove_torrent_and_data, QKeySequence(Qt::CTRL | Qt::Key_Delete));
 
     rename_torrent = new QAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18n("Rename Torrent"), this);
     connect(rename_torrent, &QAction::triggered, this, &View::renameTorrent);
@@ -190,7 +190,7 @@ void View::setupActions(KActionCollection *ac)
     manual_announce = new QAction(i18n("Manual Announce"), this);
     connect(manual_announce, &QAction::triggered, this, &View::manualAnnounce);
     ac->addAction(QStringLiteral("view_announce"), manual_announce);
-    ac->setDefaultShortcut(manual_announce, QKeySequence(Qt::SHIFT + Qt::Key_A));
+    ac->setDefaultShortcut(manual_announce, QKeySequence(Qt::SHIFT | Qt::Key_A));
 
     do_scrape = new QAction(i18n("Scrape"), this);
     connect(do_scrape, &QAction::triggered, this, &View::scrape);
@@ -228,7 +228,7 @@ void View::setupActions(KActionCollection *ac)
     check_data->setToolTip(i18n("Check all the data of a torrent"));
     connect(check_data, &QAction::triggered, this, &View::checkData);
     ac->addAction(QStringLiteral("check_data"), check_data);
-    ac->setDefaultShortcut(check_data, QKeySequence(Qt::SHIFT + Qt::Key_C));
+    ac->setDefaultShortcut(check_data, QKeySequence(Qt::SHIFT | Qt::Key_C));
 
     const GroupManager *gman = core->getGroupManager();
     for (GroupManager::CItr i = gman->begin(); i != gman->end(); i++) {
@@ -257,7 +257,7 @@ void View::setupActions(KActionCollection *ac)
     speed_limits->setToolTip(i18n("Set the speed limits of individual torrents"));
     connect(speed_limits, &QAction::triggered, this, &View::speedLimits);
     ac->addAction(QStringLiteral("speed_limits"), speed_limits);
-    ac->setDefaultShortcut(speed_limits, QKeySequence(Qt::CTRL + Qt::Key_L));
+    ac->setDefaultShortcut(speed_limits, QKeySequence(Qt::CTRL | Qt::Key_L));
 }
 
 struct StartAndStopAllVisitor {
@@ -299,7 +299,7 @@ void View::updateActions()
     bool en_add_peer = false;
     bool en_pause = false;
 
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         const TorrentStats &s = tc->getStats();
 
         if (tc->readyForPreview() && !s.multi_file_torrent)
@@ -414,7 +414,7 @@ void View::forceStartTorrents()
         // Give everybody in the selection a high priority
         int prio = qm->count();
         int idx = 0;
-        for (bt::TorrentInterface *tc : qAsConst(sel))
+        for (bt::TorrentInterface *tc : std::as_const(sel))
             tc->setPriority(prio + sel.count() - idx++);
 
         core->start(sel);
@@ -442,7 +442,7 @@ void View::removeTorrents()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (tc && !tc->getJobQueue()->runningJobs()) {
             const TorrentStats &s = tc->getStats();
             bool data_to = false;
@@ -475,7 +475,7 @@ void View::removeTorrentsAndData()
         return;
 
     QStringList names;
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         names.append(tc->getDisplayName());
     }
 
@@ -514,7 +514,7 @@ void View::manualAnnounce()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (tc->getStats().running)
             tc->updateTracker();
     }
@@ -524,7 +524,7 @@ void View::scrape()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         tc->scrapeTracker();
     }
 }
@@ -533,7 +533,7 @@ void View::previewTorrents()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (tc->readyForPreview() && !tc->getStats().multi_file_torrent) {
             openUrl(QUrl::fromLocalFile(tc->getStats().output_path));
         }
@@ -544,7 +544,7 @@ void View::openDataDir()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (tc->getStats().multi_file_torrent)
             openUrl(QUrl::fromLocalFile(tc->getStats().output_path));
         else
@@ -556,7 +556,7 @@ void View::openTorDir()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         openUrl(QUrl::fromLocalFile(tc->getTorDir()));
     }
 }
@@ -580,7 +580,7 @@ void View::moveData()
     if (!recentDirClass.isEmpty())
         KRecentDirs::add(recentDirClass, dir);
 
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (core->checkMissingFiles(tc))
             tc->changeOutputDir(dir, bt::TorrentInterface::MOVE_FILES);
     }
@@ -604,7 +604,7 @@ void View::removeFromGroup()
 
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel))
+    for (bt::TorrentInterface *tc : std::as_const(sel))
         group->removeTorrent(tc);
     core->getGroupManager()->saveGroups();
     update();
@@ -627,7 +627,7 @@ void View::checkData()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         if (tc->getStats().status != bt::ALLOCATING_DISKSPACE)
             core->doDataCheck(tc);
     }
@@ -795,7 +795,7 @@ void View::addToGroupItemTriggered()
 
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    for (bt::TorrentInterface *tc : qAsConst(sel)) {
+    for (bt::TorrentInterface *tc : std::as_const(sel)) {
         g->addTorrent(tc, false);
     }
     core->getGroupManager()->saveGroups();
@@ -807,7 +807,7 @@ void View::addToNewGroup()
     if (g) {
         QList<bt::TorrentInterface *> sel;
         getSelection(sel);
-        for (bt::TorrentInterface *tc : qAsConst(sel)) {
+        for (bt::TorrentInterface *tc : std::as_const(sel)) {
             g->addTorrent(tc, false);
         }
         core->getGroupManager()->saveGroups();
