@@ -127,7 +127,7 @@ GroupManager::GroupManager()
                                                            QStringLiteral("/all/passive/uploads"));
     defaults << new UngroupedGroup(this);
 
-    for (Group *g : qAsConst(defaults))
+    for (Group *g : std::as_const(defaults))
         groups.insert(g->groupName(), g);
 }
 
@@ -161,7 +161,7 @@ void GroupManager::removeGroup(Group *g)
 
 bool GroupManager::canRemove(const Group *g) const
 {
-    return g->groupFlags() & Group::CUSTOM_GROUP;
+    return g && g->groupFlags() & Group::CUSTOM_GROUP;
 }
 
 Group *GroupManager::find(const QString &name)
