@@ -56,9 +56,9 @@ void PluginManager::loadPluginList()
 
 void PluginManager::loadPlugins()
 {
-    const KConfigGroup cfg = KSharedConfig::openConfig()->group("Plugins");
+    const KConfigGroup cfg = KSharedConfig::openConfig()->group(QStringLiteral("Plugins"));
     int idx = 0;
-    for (const KPluginMetaData &data : qAsConst(pluginsMetaData)) {
+    for (const KPluginMetaData &data : std::as_const(pluginsMetaData)) {
         if (loaded.contains(idx) && !data.isEnabled(cfg)) {
             // unload it
             unload(data, idx);
