@@ -19,11 +19,10 @@
 #include <KConfigGroup>
 #include <KFileWidget>
 #include <KIO/ApplicationLauncherJob>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KMessageBox_KTCompat>
 #include <KRecentDirs>
 #include <KSharedConfig>
 
@@ -49,12 +48,12 @@ FileView::FileView(QWidget *parent)
     , show_list_of_files(false)
     , header_state_loaded(false)
 {
+    auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setSpacing(0);
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(0);
+    mainLayout->addLayout(layout);
     QVBoxLayout *vbox = new QVBoxLayout();
-    vbox->setContentsMargins(0, 0, 0, 0);
-    vbox->setSpacing(0);
     view = new QTreeView(this);
     toolbar = new QToolBar(this);
     toolbar->setOrientation(Qt::Vertical);
@@ -71,6 +70,11 @@ FileView::FileView(QWidget *parent)
     vbox->addWidget(view);
     layout->addItem(vbox);
 
+    auto separator = new QFrame(this);
+    separator->setFrameShape(QFrame::HLine);
+    separator->setFixedHeight(1);
+    mainLayout->addWidget(separator);
+
     view->setContextMenuPolicy(Qt::CustomContextMenu);
     view->setRootIsDecorated(false);
     view->setSortingEnabled(true);
@@ -78,6 +82,7 @@ FileView::FileView(QWidget *parent)
     view->setSelectionMode(QAbstractItemView::ExtendedSelection);
     view->setSelectionBehavior(QAbstractItemView::SelectRows);
     view->setUniformRowHeights(true);
+    view->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags<Qt::Edge>{Qt::LeftEdge}));
 
     proxy_model = new TreeFilterModel(this);
     proxy_model->setSortRole(Qt::UserRole);
@@ -271,7 +276,7 @@ void FileView::openWith()
 {
     auto *job = new KIO::ApplicationLauncherJob();
     job->setUrls({QUrl::fromLocalFile(preview_path)});
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
 }
 
@@ -471,7 +476,7 @@ void FileView::saveState(KSharedConfigPtr cfg)
     if (!model)
         return;
 
-    KConfigGroup g = cfg->group("FileView");
+    KConfigGroup g = cfg->group(QStringLiteral("FileView"));
     QByteArray s = view->header()->saveState();
     g.writeEntry("state", s.toBase64());
     g.writeEntry("show_list_of_files", show_list_of_files);
@@ -479,7 +484,7 @@ void FileView::saveState(KSharedConfigPtr cfg)
 
 void FileView::loadState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("FileView");
+    KConfigGroup g = cfg->group(QStringLiteral("FileView"));
     QByteArray s = g.readEntry("state", QByteArray());
     if (!s.isEmpty()) {
         QHeaderView *v = view->header();
